==> messagelib-23.04.0-1-armv7h.pkg.tar.xz: usr/lib/cmake/KPim5MessageComposer/KPim5MessageComposerConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was KPimMessageComposerConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/KPim5MessageComposer" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################
include(CMakeFindDependencyMacro)
find_dependency(KPim5Mime "5.23.0")
find_dependency(KPim5MessageCore "5.23.0")
find_dependency(KPim5TemplateParser "5.23.0")
find_dependency(KF5PimCommon "5.23.0")
find_dependency(KF5PimCommonAkonadi "5.23.0")
find_dependency(KPim5Akonadi "5.23.0")
find_dependency(KPim5IdentityManagement "5.23.0")
find_dependency(KPim5AkonadiMime "5.23.0")
find_dependency(KPim5Libkleo "5.23.0")
find_dependency(KPim5MessageViewer "5.23.0")
find_dependency(KF5TextAutoCorrection "1.0.0")
include("${CMAKE_CURRENT_LIST_DIR}/KPim5MessageComposerTargets.cmake")

==> messagelib-23.04.1-1-armv7h.pkg.tar.xz: usr/lib/cmake/KPim5MessageComposer/KPim5MessageComposerConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was KPimMessageComposerConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/KPim5MessageComposer" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################
include(CMakeFindDependencyMacro)
find_dependency(KPim5Mime "5.23.1")
find_dependency(KPim5MessageCore "5.23.1")
find_dependency(KPim5TemplateParser "5.23.1")
find_dependency(KF5PimCommon "5.23.1")
find_dependency(KF5PimCommonAkonadi "5.23.1")
find_dependency(KPim5Akonadi "5.23.1")
find_dependency(KPim5IdentityManagement "5.23.1")
find_dependency(KPim5AkonadiMime "5.23.1")
find_dependency(KPim5Libkleo "5.23.1")
find_dependency(KPim5MessageViewer "5.23.1")
if (TRUE)
	find_dependency(KF5TextAutoCorrectionWidgets "1.0.0")
else ()
	find_dependency(KF5TextAutoCorrection "1.0.0")
endif ()
include("${CMAKE_CURRENT_LIST_DIR}/KPim5MessageComposerTargets.cmake")
